# pytomofilt
Pytomofilt is a python package for tomographic filtering of synthetic seismic velocity models using resolution operators from the RTS suite of models, which includes S20RTS, S40RTS, and SP12RTS. Pytomofilt is released under an MIT license.


